# io.swagger.client - Kotlin client library for UV - A Weather Source API

## Requires

* Kotlin 1.4.30
* Gradle 5.3

## Build

First, create the gradle wrapper script:

```
gradle wrapper
```

Then, run:

```
./gradlew check assemble
```

This runs all tests and packages the library.

## Features/Implementation Notes

* Supports JSON inputs/outputs, File inputs, and Form inputs.
* Supports collection formats for query parameters: csv, tsv, ssv, pipes.
* Some Kotlin and Java types are fully qualified to avoid conflicts with types defined in Swagger definitions.
* Implementation of ApiClient is intended to reduce method counts, specifically to benefit Android targets.

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://uv.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**dmasDmaIdDaysDateGet**](docs/DmasApi.md#dmasdmaiddaysdateget) | **GET** /dmas/{dmaId}/days/{date} | A day of UV data for a DMA.
*DmasApi* | [**dmasDmaIdDaysDateStartdateEndGet**](docs/DmasApi.md#dmasdmaiddaysdatestartdateendget) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a DMA.
*DmasApi* | [**dmasDmaIdDaysGet**](docs/DmasApi.md#dmasdmaiddaysget) | **GET** /dmas/{dmaId}/days | The complete daily UV forecast for a DMA.
*DmasApi* | [**dmasDmaIdHoursGet**](docs/DmasApi.md#dmasdmaidhoursget) | **GET** /dmas/{dmaId}/hours | The complete hourly UV forecast for a DMA
*DmasApi* | [**dmasDmaIdHoursTimestampGet**](docs/DmasApi.md#dmasdmaidhourstimestampget) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of UV data for a DMA
*DmasApi* | [**dmasDmaIdHoursTimestampStarttimestampEndGet**](docs/DmasApi.md#dmasdmaidhourstimestampstarttimestampendget) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a DMA.
*OnpointsApi* | [**onpointsOnpointIdDaysDateGet**](docs/OnpointsApi.md#onpointsonpointiddaysdateget) | **GET** /onpoints/{onpointId}/days/{date} | A day of UV data for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdDaysDateStartdateEndGet**](docs/OnpointsApi.md#onpointsonpointiddaysdatestartdateendget) | **GET** /onpoints/{onpointId}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdDaysGet**](docs/OnpointsApi.md#onpointsonpointiddaysget) | **GET** /onpoints/{onpointId}/days | The complete daily UV forecast for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursGet**](docs/OnpointsApi.md#onpointsonpointidhoursget) | **GET** /onpoints/{onpointId}/hours | The complete hourly UV forecast for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursTimestampGet**](docs/OnpointsApi.md#onpointsonpointidhourstimestampget) | **GET** /onpoints/{onpointId}/hours/{timestamp} | An hour of UV data for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursTimestampStarttimestampEndGet**](docs/OnpointsApi.md#onpointsonpointidhourstimestampstarttimestampendget) | **GET** /onpoints/{onpointId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudeDaysDateGet**](docs/PointsApi.md#pointslatitudelongitudedaysdateget) | **GET** /points/{latitude},{longitude}/days/{date} | A day of UV data for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeDaysDateStartdateEndGet**](docs/PointsApi.md#pointslatitudelongitudedaysdatestartdateendget) | **GET** /points/{latitude},{longitude}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeDaysGet**](docs/PointsApi.md#pointslatitudelongitudedaysget) | **GET** /points/{latitude},{longitude}/days | The complete daily UV forecast for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursGet**](docs/PointsApi.md#pointslatitudelongitudehoursget) | **GET** /points/{latitude},{longitude}/hours | The complete hourly UV forecast for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursTimestampGet**](docs/PointsApi.md#pointslatitudelongitudehourstimestampget) | **GET** /points/{latitude},{longitude}/hours/{timestamp} | An hour of UV data for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursTimestampStarttimestampEndGet**](docs/PointsApi.md#pointslatitudelongitudehourstimestampstarttimestampendget) | **GET** /points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a Latitude/Longitude point.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysDateGet**](docs/PostcodesApi.md#postcodespostcodecountrycodedaysdateget) | **GET** /postcodes/{postcode},{countryCode}/days/{date} | A day of UV data for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysDateStartdateEndGet**](docs/PostcodesApi.md#postcodespostcodecountrycodedaysdatestartdateendget) | **GET** /postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysGet**](docs/PostcodesApi.md#postcodespostcodecountrycodedaysget) | **GET** /postcodes/{postcode},{countryCode}/days | The complete daily UV forecast for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursGet**](docs/PostcodesApi.md#postcodespostcodecountrycodehoursget) | **GET** /postcodes/{postcode},{countryCode}/hours | The complete hourly UV forecast for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursTimestampGet**](docs/PostcodesApi.md#postcodespostcodecountrycodehourstimestampget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestamp} | An hour of UV data for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet**](docs/PostcodesApi.md#postcodespostcodecountrycodehourstimestampstarttimestampendget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a postcode.

<a name="documentation-for-models"></a>
## Documentation for Models

 - [io.swagger.client.models.BoundingPoints](docs/BoundingPoints.md)
 - [io.swagger.client.models.BoundingPointsInner](docs/BoundingPointsInner.md)
 - [io.swagger.client.models.CountryCode](docs/CountryCode.md)
 - [io.swagger.client.models.CountryName](docs/CountryName.md)
 - [io.swagger.client.models.Date](docs/Date.md)
 - [io.swagger.client.models.DateEnd](docs/DateEnd.md)
 - [io.swagger.client.models.DateRangeObj](docs/DateRangeObj.md)
 - [io.swagger.client.models.DateStart](docs/DateStart.md)
 - [io.swagger.client.models.Distance](docs/Distance.md)
 - [io.swagger.client.models.DistancePop](docs/DistancePop.md)
 - [io.swagger.client.models.DmaId](docs/DmaId.md)
 - [io.swagger.client.models.DmaName](docs/DmaName.md)
 - [io.swagger.client.models.DmaObj](docs/DmaObj.md)
 - [io.swagger.client.models.Elevation](docs/Elevation.md)
 - [io.swagger.client.models.ErrorObj](docs/ErrorObj.md)
 - [io.swagger.client.models.FieldListDayObj](docs/FieldListDayObj.md)
 - [io.swagger.client.models.FieldListHourObj](docs/FieldListHourObj.md)
 - [io.swagger.client.models.Fields](docs/Fields.md)
 - [io.swagger.client.models.Grid](docs/Grid.md)
 - [io.swagger.client.models.Latitude](docs/Latitude.md)
 - [io.swagger.client.models.Longitude](docs/Longitude.md)
 - [io.swagger.client.models.OnpointId](docs/OnpointId.md)
 - [io.swagger.client.models.OnpointObj](docs/OnpointObj.md)
 - [io.swagger.client.models.PointObj](docs/PointObj.md)
 - [io.swagger.client.models.Population](docs/Population.md)
 - [io.swagger.client.models.Postcode](docs/Postcode.md)
 - [io.swagger.client.models.PostcodeObj](docs/PostcodeObj.md)
 - [io.swagger.client.models.SamplePoints](docs/SamplePoints.md)
 - [io.swagger.client.models.SamplePointsInner](docs/SamplePointsInner.md)
 - [io.swagger.client.models.SubdivCode](docs/SubdivCode.md)
 - [io.swagger.client.models.SubdivName](docs/SubdivName.md)
 - [io.swagger.client.models.Timestamp](docs/Timestamp.md)
 - [io.swagger.client.models.TimestampEnd](docs/TimestampEnd.md)
 - [io.swagger.client.models.TimestampInit](docs/TimestampInit.md)
 - [io.swagger.client.models.TimestampRangeObj](docs/TimestampRangeObj.md)
 - [io.swagger.client.models.TimestampStart](docs/TimestampStart.md)
 - [io.swagger.client.models.Timezone](docs/Timezone.md)
 - [io.swagger.client.models.UvDayArr](docs/UvDayArr.md)
 - [io.swagger.client.models.UvDayObj](docs/UvDayObj.md)
 - [io.swagger.client.models.UvDmaDayObj](docs/UvDmaDayObj.md)
 - [io.swagger.client.models.UvDmaHourObj](docs/UvDmaHourObj.md)
 - [io.swagger.client.models.UvHourArr](docs/UvHourArr.md)
 - [io.swagger.client.models.UvHourObj](docs/UvHourObj.md)
 - [io.swagger.client.models.UvIndex](docs/UvIndex.md)
 - [io.swagger.client.models.UvIndexMax](docs/UvIndexMax.md)
 - [io.swagger.client.models.UvOnpointDayObj](docs/UvOnpointDayObj.md)
 - [io.swagger.client.models.UvOnpointHourObj](docs/UvOnpointHourObj.md)
 - [io.swagger.client.models.UvPointDayObj](docs/UvPointDayObj.md)
 - [io.swagger.client.models.UvPointHourObj](docs/UvPointHourObj.md)
 - [io.swagger.client.models.UvPostcodeDayObj](docs/UvPostcodeDayObj.md)
 - [io.swagger.client.models.UvPostcodeHourObj](docs/UvPostcodeHourObj.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="ApiKeyAuth"></a>
### ApiKeyAuth


