# DmasApi

All URIs are relative to *https://uv.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**dmasDmaIdDaysDateGet**](DmasApi.md#dmasDmaIdDaysDateGet) | **GET** /dmas/{dmaId}/days/{date} | A day of UV data for a DMA.
[**dmasDmaIdDaysDateStartdateEndGet**](DmasApi.md#dmasDmaIdDaysDateStartdateEndGet) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a DMA.
[**dmasDmaIdDaysGet**](DmasApi.md#dmasDmaIdDaysGet) | **GET** /dmas/{dmaId}/days | The complete daily UV forecast for a DMA.
[**dmasDmaIdHoursGet**](DmasApi.md#dmasDmaIdHoursGet) | **GET** /dmas/{dmaId}/hours | The complete hourly UV forecast for a DMA
[**dmasDmaIdHoursTimestampGet**](DmasApi.md#dmasDmaIdHoursTimestampGet) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of UV data for a DMA
[**dmasDmaIdHoursTimestampStarttimestampEndGet**](DmasApi.md#dmasDmaIdHoursTimestampStarttimestampEndGet) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a DMA.

<a name="dmasDmaIdDaysDateGet"></a>
# **dmasDmaIdDaysDateGet**
> UvDmaDayObj dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale)

A day of UV data for a DMA.

Returns a single day of UV data for a Designated Market Area. The provided date must exist within the current valid 5-day forecast range, or it must be a historical date.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = DmasApi()
val dmaId : kotlin.Int = 56 // kotlin.Int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
val date : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvDmaDayObj = apiInstance.dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling DmasApi#dmasDmaIdDaysDateGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling DmasApi#dmasDmaIdDaysDateGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dmaId** | **kotlin.Int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **date** | **java.time.LocalDate**| An date formatted as a RFC3339 date value. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvDmaDayObj**](UvDmaDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="dmasDmaIdDaysDateStartdateEndGet"></a>
# **dmasDmaIdDaysDateStartdateEndGet**
> UvDmaDayObj dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale)

A contiguous range of daily UV data for a DMA.

Returns a contiguous range of daily UV data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = DmasApi()
val dmaId : kotlin.Int = 56 // kotlin.Int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
val dateStart : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
val dateEnd : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvDmaDayObj = apiInstance.dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling DmasApi#dmasDmaIdDaysDateStartdateEndGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling DmasApi#dmasDmaIdDaysDateStartdateEndGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dmaId** | **kotlin.Int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **dateStart** | **java.time.LocalDate**| An date formatted as a RFC3339 date value that must occur temporally before dateEnd. |
 **dateEnd** | **java.time.LocalDate**| An date formatted as a RFC3339 date value that must occur temporally after dateStart. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvDmaDayObj**](UvDmaDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="dmasDmaIdDaysGet"></a>
# **dmasDmaIdDaysGet**
> UvDmaDayObj dmasDmaIdDaysGet(dmaId, fields, unitScale)

The complete daily UV forecast for a DMA.

Returns the complete set of UV forecast data for a Designated Market Area.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = DmasApi()
val dmaId : kotlin.Int = 56 // kotlin.Int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvDmaDayObj = apiInstance.dmasDmaIdDaysGet(dmaId, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling DmasApi#dmasDmaIdDaysGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling DmasApi#dmasDmaIdDaysGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dmaId** | **kotlin.Int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvDmaDayObj**](UvDmaDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="dmasDmaIdHoursGet"></a>
# **dmasDmaIdHoursGet**
> UvDmaHourObj dmasDmaIdHoursGet(dmaId, fields, unitScale)

The complete hourly UV forecast for a DMA

Returns the complete set of UV forecast data for a Designated Market Area.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = DmasApi()
val dmaId : kotlin.Int = 56 // kotlin.Int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvDmaHourObj = apiInstance.dmasDmaIdHoursGet(dmaId, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling DmasApi#dmasDmaIdHoursGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling DmasApi#dmasDmaIdHoursGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dmaId** | **kotlin.Int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvDmaHourObj**](UvDmaHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="dmasDmaIdHoursTimestampGet"></a>
# **dmasDmaIdHoursTimestampGet**
> UvDmaHourObj dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale)

An hour of UV data for a DMA

Returns a single hour of UV data for a Designated Market Area. The provided timestamp must exist within the current valid 5-day forecast range, or it must be a historical timestamp.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = DmasApi()
val dmaId : kotlin.Int = 56 // kotlin.Int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
val timestamp : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvDmaHourObj = apiInstance.dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling DmasApi#dmasDmaIdHoursTimestampGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling DmasApi#dmasDmaIdHoursTimestampGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dmaId** | **kotlin.Int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **timestamp** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvDmaHourObj**](UvDmaHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="dmasDmaIdHoursTimestampStarttimestampEndGet"></a>
# **dmasDmaIdHoursTimestampStarttimestampEndGet**
> UvDmaHourObj dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale)

A contiguous range of hourly UV data for a DMA.

Returns a contiguous range of hourly UV data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = DmasApi()
val dmaId : kotlin.Int = 56 // kotlin.Int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
val timestampStart : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
val timestampEnd : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvDmaHourObj = apiInstance.dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling DmasApi#dmasDmaIdHoursTimestampStarttimestampEndGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling DmasApi#dmasDmaIdHoursTimestampStarttimestampEndGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dmaId** | **kotlin.Int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **timestampStart** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. |
 **timestampEnd** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvDmaHourObj**](UvDmaHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

