# PointsApi

All URIs are relative to *https://uv.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**pointsLatitudelongitudeDaysDateGet**](PointsApi.md#pointsLatitudelongitudeDaysDateGet) | **GET** /points/{latitude},{longitude}/days/{date} | A day of UV data for a Latitude/Longitude point.
[**pointsLatitudelongitudeDaysDateStartdateEndGet**](PointsApi.md#pointsLatitudelongitudeDaysDateStartdateEndGet) | **GET** /points/{latitude},{longitude}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a Latitude/Longitude point.
[**pointsLatitudelongitudeDaysGet**](PointsApi.md#pointsLatitudelongitudeDaysGet) | **GET** /points/{latitude},{longitude}/days | The complete daily UV forecast for a Latitude/Longitude point.
[**pointsLatitudelongitudeHoursGet**](PointsApi.md#pointsLatitudelongitudeHoursGet) | **GET** /points/{latitude},{longitude}/hours | The complete hourly UV forecast for a Latitude/Longitude point.
[**pointsLatitudelongitudeHoursTimestampGet**](PointsApi.md#pointsLatitudelongitudeHoursTimestampGet) | **GET** /points/{latitude},{longitude}/hours/{timestamp} | An hour of UV data for a Latitude/Longitude point.
[**pointsLatitudelongitudeHoursTimestampStarttimestampEndGet**](PointsApi.md#pointsLatitudelongitudeHoursTimestampStarttimestampEndGet) | **GET** /points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a Latitude/Longitude point.

<a name="pointsLatitudelongitudeDaysDateGet"></a>
# **pointsLatitudelongitudeDaysDateGet**
> UvPointDayObj pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale)

A day of UV data for a Latitude/Longitude point.

Returns a single day of UV data for a Latitude/Longitude point. The provided date must exist within the current valid 5-day forecast range, or it must be a historical date.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PointsApi()
val latitude : kotlin.Float = 3.4 // kotlin.Float | A latitude value between -90° and 90°.
val longitude : kotlin.Float = 3.4 // kotlin.Float | A longitude value between -180° (West) and 180° (East).
val date : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPointDayObj = apiInstance.pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PointsApi#pointsLatitudelongitudeDaysDateGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PointsApi#pointsLatitudelongitudeDaysDateGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **kotlin.Float**| A latitude value between -90° and 90°. |
 **longitude** | **kotlin.Float**| A longitude value between -180° (West) and 180° (East). |
 **date** | **java.time.LocalDate**| An date formatted as a RFC3339 date value. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPointDayObj**](UvPointDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pointsLatitudelongitudeDaysDateStartdateEndGet"></a>
# **pointsLatitudelongitudeDaysDateStartdateEndGet**
> UvPointDayObj pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale)

A contiguous range of daily UV data for a Latitude/Longitude point.

Returns a contiguous range of daily UV data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration  **IMPORTANT:** To authenticate to the Weather Source Uv API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PointsApi()
val latitude : kotlin.Float = 3.4 // kotlin.Float | A latitude value between -90° and 90°.
val longitude : kotlin.Float = 3.4 // kotlin.Float | A longitude value between -180° (West) and 180° (East).
val dateStart : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
val dateEnd : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPointDayObj = apiInstance.pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PointsApi#pointsLatitudelongitudeDaysDateStartdateEndGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PointsApi#pointsLatitudelongitudeDaysDateStartdateEndGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **kotlin.Float**| A latitude value between -90° and 90°. |
 **longitude** | **kotlin.Float**| A longitude value between -180° (West) and 180° (East). |
 **dateStart** | **java.time.LocalDate**| An date formatted as a RFC3339 date value that must occur temporally before dateEnd. |
 **dateEnd** | **java.time.LocalDate**| An date formatted as a RFC3339 date value that must occur temporally after dateStart. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPointDayObj**](UvPointDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pointsLatitudelongitudeDaysGet"></a>
# **pointsLatitudelongitudeDaysGet**
> UvPointDayObj pointsLatitudelongitudeDaysGet(latitude, longitude, fields, unitScale)

The complete daily UV forecast for a Latitude/Longitude point.

Returns the complete set of daily UV forecast data for a Latitude/Longitude point.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PointsApi()
val latitude : kotlin.Float = 3.4 // kotlin.Float | A latitude value between -90° and 90°.
val longitude : kotlin.Float = 3.4 // kotlin.Float | A longitude value between -180° (West) and 180° (East).
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPointDayObj = apiInstance.pointsLatitudelongitudeDaysGet(latitude, longitude, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PointsApi#pointsLatitudelongitudeDaysGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PointsApi#pointsLatitudelongitudeDaysGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **kotlin.Float**| A latitude value between -90° and 90°. |
 **longitude** | **kotlin.Float**| A longitude value between -180° (West) and 180° (East). |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPointDayObj**](UvPointDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pointsLatitudelongitudeHoursGet"></a>
# **pointsLatitudelongitudeHoursGet**
> UvPointHourObj pointsLatitudelongitudeHoursGet(latitude, longitude, fields, unitScale)

The complete hourly UV forecast for a Latitude/Longitude point.

Returns the complete set of UV forecast data for a Latitude/Longitude point.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PointsApi()
val latitude : kotlin.Float = 3.4 // kotlin.Float | A latitude value between -90° and 90°.
val longitude : kotlin.Float = 3.4 // kotlin.Float | A longitude value between -180° (West) and 180° (East).
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPointHourObj = apiInstance.pointsLatitudelongitudeHoursGet(latitude, longitude, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PointsApi#pointsLatitudelongitudeHoursGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PointsApi#pointsLatitudelongitudeHoursGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **kotlin.Float**| A latitude value between -90° and 90°. |
 **longitude** | **kotlin.Float**| A longitude value between -180° (West) and 180° (East). |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPointHourObj**](UvPointHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pointsLatitudelongitudeHoursTimestampGet"></a>
# **pointsLatitudelongitudeHoursTimestampGet**
> UvPointHourObj pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale)

An hour of UV data for a Latitude/Longitude point.

Returns a single hour of UV data for a Latitude/Longitude point. The provided timestamp must exist within the current valid 5-day forecast range, or it must be a historical timestamp.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PointsApi()
val latitude : kotlin.Float = 3.4 // kotlin.Float | A latitude value between -90° and 90°.
val longitude : kotlin.Float = 3.4 // kotlin.Float | A longitude value between -180° (West) and 180° (East).
val timestamp : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPointHourObj = apiInstance.pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PointsApi#pointsLatitudelongitudeHoursTimestampGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PointsApi#pointsLatitudelongitudeHoursTimestampGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **kotlin.Float**| A latitude value between -90° and 90°. |
 **longitude** | **kotlin.Float**| A longitude value between -180° (West) and 180° (East). |
 **timestamp** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPointHourObj**](UvPointHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pointsLatitudelongitudeHoursTimestampStarttimestampEndGet"></a>
# **pointsLatitudelongitudeHoursTimestampStarttimestampEndGet**
> UvPointHourObj pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale)

A contiguous range of hourly UV data for a Latitude/Longitude point.

Returns a contiguous range of hourly ECMWF forecast data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PointsApi()
val latitude : kotlin.Float = 3.4 // kotlin.Float | A latitude value between -90° and 90°.
val longitude : kotlin.Float = 3.4 // kotlin.Float | A longitude value between -180° (West) and 180° (East).
val timestampStart : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
val timestampEnd : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPointHourObj = apiInstance.pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PointsApi#pointsLatitudelongitudeHoursTimestampStarttimestampEndGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PointsApi#pointsLatitudelongitudeHoursTimestampStarttimestampEndGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **latitude** | **kotlin.Float**| A latitude value between -90° and 90°. |
 **longitude** | **kotlin.Float**| A longitude value between -180° (West) and 180° (East). |
 **timestampStart** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. |
 **timestampEnd** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPointHourObj**](UvPointHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

