# PostcodesApi

All URIs are relative to *https://uv.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**postcodesPostcodecountryCodeDaysDateGet**](PostcodesApi.md#postcodesPostcodecountryCodeDaysDateGet) | **GET** /postcodes/{postcode},{countryCode}/days/{date} | A day of UV data for a postcode.
[**postcodesPostcodecountryCodeDaysDateStartdateEndGet**](PostcodesApi.md#postcodesPostcodecountryCodeDaysDateStartdateEndGet) | **GET** /postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a postcode.
[**postcodesPostcodecountryCodeDaysGet**](PostcodesApi.md#postcodesPostcodecountryCodeDaysGet) | **GET** /postcodes/{postcode},{countryCode}/days | The complete daily UV forecast for a postcode.
[**postcodesPostcodecountryCodeHoursGet**](PostcodesApi.md#postcodesPostcodecountryCodeHoursGet) | **GET** /postcodes/{postcode},{countryCode}/hours | The complete hourly UV forecast for a postcode.
[**postcodesPostcodecountryCodeHoursTimestampGet**](PostcodesApi.md#postcodesPostcodecountryCodeHoursTimestampGet) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestamp} | An hour of UV data for a postcode.
[**postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet**](PostcodesApi.md#postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a postcode.

<a name="postcodesPostcodecountryCodeDaysDateGet"></a>
# **postcodesPostcodecountryCodeDaysDateGet**
> UvPostcodeDayObj postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale)

A day of UV data for a postcode.

Returns a single day of UV data for a postcode. The provided date must exist within the current valid 5-day forecast range, or it must be a historical date.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PostcodesApi()
val postcode : kotlin.String = postcode_example // kotlin.String | A postcode string.
val countryCode : kotlin.String = countryCode_example // kotlin.String | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
val date : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPostcodeDayObj = apiInstance.postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PostcodesApi#postcodesPostcodecountryCodeDaysDateGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PostcodesApi#postcodesPostcodecountryCodeDaysDateGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **kotlin.String**| A postcode string. |
 **countryCode** | **kotlin.String**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **date** | **java.time.LocalDate**| An date formatted as a RFC3339 date value. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPostcodeDayObj**](UvPostcodeDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postcodesPostcodecountryCodeDaysDateStartdateEndGet"></a>
# **postcodesPostcodecountryCodeDaysDateStartdateEndGet**
> UvPostcodeDayObj postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale)

A contiguous range of daily UV data for a postcode.

Returns a contiguous range of daily ECMWF forecast data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PostcodesApi()
val postcode : kotlin.String = postcode_example // kotlin.String | A postcode string.
val countryCode : kotlin.String = countryCode_example // kotlin.String | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
val dateStart : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
val dateEnd : java.time.LocalDate = 2013-10-20 // java.time.LocalDate | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPostcodeDayObj = apiInstance.postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PostcodesApi#postcodesPostcodecountryCodeDaysDateStartdateEndGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PostcodesApi#postcodesPostcodecountryCodeDaysDateStartdateEndGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **kotlin.String**| A postcode string. |
 **countryCode** | **kotlin.String**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **dateStart** | **java.time.LocalDate**| An date formatted as a RFC3339 date value that must occur temporally before dateEnd. |
 **dateEnd** | **java.time.LocalDate**| An date formatted as a RFC3339 date value that must occur temporally after dateStart. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPostcodeDayObj**](UvPostcodeDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postcodesPostcodecountryCodeDaysGet"></a>
# **postcodesPostcodecountryCodeDaysGet**
> UvPostcodeDayObj postcodesPostcodecountryCodeDaysGet(postcode, countryCode, fields, unitScale)

The complete daily UV forecast for a postcode.

Returns the complete set of UV forecast data for a postcode.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PostcodesApi()
val postcode : kotlin.String = postcode_example // kotlin.String | A postcode string.
val countryCode : kotlin.String = countryCode_example // kotlin.String | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPostcodeDayObj = apiInstance.postcodesPostcodecountryCodeDaysGet(postcode, countryCode, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PostcodesApi#postcodesPostcodecountryCodeDaysGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PostcodesApi#postcodesPostcodecountryCodeDaysGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **kotlin.String**| A postcode string. |
 **countryCode** | **kotlin.String**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  | [enum: timestampInit, uvIndexMax, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPostcodeDayObj**](UvPostcodeDayObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postcodesPostcodecountryCodeHoursGet"></a>
# **postcodesPostcodecountryCodeHoursGet**
> UvPostcodeHourObj postcodesPostcodecountryCodeHoursGet(postcode, countryCode, fields, unitScale)

The complete hourly UV forecast for a postcode.

Returns the complete set of UV forecast data for a postcode.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PostcodesApi()
val postcode : kotlin.String = postcode_example // kotlin.String | A postcode string.
val countryCode : kotlin.String = countryCode_example // kotlin.String | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPostcodeHourObj = apiInstance.postcodesPostcodecountryCodeHoursGet(postcode, countryCode, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PostcodesApi#postcodesPostcodecountryCodeHoursGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PostcodesApi#postcodesPostcodecountryCodeHoursGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **kotlin.String**| A postcode string. |
 **countryCode** | **kotlin.String**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPostcodeHourObj**](UvPostcodeHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postcodesPostcodecountryCodeHoursTimestampGet"></a>
# **postcodesPostcodecountryCodeHoursTimestampGet**
> UvPostcodeHourObj postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale)

An hour of UV data for a postcode.

Returns a single hour of ECMWF forecast data for a postcode. The provided timestamp must exist within the current valid 5-day forecast range, or it must be a historical timestamp.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PostcodesApi()
val postcode : kotlin.String = postcode_example // kotlin.String | A postcode string.
val countryCode : kotlin.String = countryCode_example // kotlin.String | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
val timestamp : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPostcodeHourObj = apiInstance.postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PostcodesApi#postcodesPostcodecountryCodeHoursTimestampGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PostcodesApi#postcodesPostcodecountryCodeHoursTimestampGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **kotlin.String**| A postcode string. |
 **countryCode** | **kotlin.String**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **timestamp** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPostcodeHourObj**](UvPostcodeHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet"></a>
# **postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet**
> UvPostcodeHourObj postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale)

A contiguous range of hourly UV data for a postcode.

Returns a contiguous range of hourly UV data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = PostcodesApi()
val postcode : kotlin.String = postcode_example // kotlin.String | A postcode string.
val countryCode : kotlin.String = countryCode_example // kotlin.String | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
val timestampStart : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
val timestampEnd : java.time.LocalDateTime = 2013-10-20T19:20:30+01:00 // java.time.LocalDateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
val fields : kotlin.Array<kotlin.String> =  // kotlin.Array<kotlin.String> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* 
val unitScale : kotlin.String = unitScale_example // kotlin.String | The unit scale for returned values.<br>
try {
    val result : UvPostcodeHourObj = apiInstance.postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PostcodesApi#postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PostcodesApi#postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **kotlin.String**| A postcode string. |
 **countryCode** | **kotlin.String**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **timestampStart** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. |
 **timestampEnd** | **java.time.LocalDateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. |
 **fields** | [**kotlin.Array&lt;kotlin.String&gt;**](kotlin.String.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  | [enum: timestampInit, uvIndex, all]
 **unitScale** | **kotlin.String**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL] [enum: IMPERIAL, METRIC, SI]

### Return type

[**UvPostcodeHourObj**](UvPostcodeHourObj.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

