/**
 * UV - A Weather Source API
 * Daily and hourly UV data for latitude/longitude points, ZIP/Postal Codes, and Designated Market Areas. UV forecast is up to 5 days out from the current day. Historical UV data is also available. The Weather Source UV API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
package io.swagger.client.apis

import io.swagger.client.models.ErrorObj
import io.swagger.client.models.UvPointDayObj
import io.swagger.client.models.UvPointHourObj

import io.swagger.client.infrastructure.*

class PointsApi(basePath: kotlin.String = "https://uv.weathersourceapis.com/v2") : ApiClient(basePath) {

    /**
     * A day of UV data for a Latitude/Longitude point.
     * Returns a single day of UV data for a Latitude/Longitude point. The provided date must exist within the current valid 5-day forecast range, or it must be a historical date.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param date An date formatted as a RFC3339 date value. 
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return UvPointDayObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeDaysDateGet(latitude: kotlin.Float, longitude: kotlin.Float, date: java.time.LocalDate, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): UvPointDayObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/days/{date}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "date" + "}", "$date"), query = localVariableQuery
        )
        val response = request<UvPointDayObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as UvPointDayObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * A contiguous range of daily UV data for a Latitude/Longitude point.
     * Returns a contiguous range of daily UV data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration  **IMPORTANT:** To authenticate to the Weather Source Uv API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd. 
     * @param dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart. 
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return UvPointDayObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: kotlin.Float, longitude: kotlin.Float, dateStart: java.time.LocalDate, dateEnd: java.time.LocalDate, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): UvPointDayObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/days/{dateStart},{dateEnd}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "dateStart" + "}", "$dateStart").replace("{" + "dateEnd" + "}", "$dateEnd"), query = localVariableQuery
        )
        val response = request<UvPointDayObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as UvPointDayObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The complete daily UV forecast for a Latitude/Longitude point.
     * Returns the complete set of daily UV forecast data for a Latitude/Longitude point.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return UvPointDayObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeDaysGet(latitude: kotlin.Float, longitude: kotlin.Float, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): UvPointDayObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/days".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude"), query = localVariableQuery
        )
        val response = request<UvPointDayObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as UvPointDayObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The complete hourly UV forecast for a Latitude/Longitude point.
     * Returns the complete set of UV forecast data for a Latitude/Longitude point.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return UvPointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHoursGet(latitude: kotlin.Float, longitude: kotlin.Float, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): UvPointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hours".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude"), query = localVariableQuery
        )
        val response = request<UvPointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as UvPointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * An hour of UV data for a Latitude/Longitude point.
     * Returns a single hour of UV data for a Latitude/Longitude point. The provided timestamp must exist within the current valid 5-day forecast range, or it must be a historical timestamp.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return UvPointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHoursTimestampGet(latitude: kotlin.Float, longitude: kotlin.Float, timestamp: java.time.LocalDateTime, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): UvPointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hours/{timestamp}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "timestamp" + "}", "$timestamp"), query = localVariableQuery
        )
        val response = request<UvPointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as UvPointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * A contiguous range of hourly UV data for a Latitude/Longitude point.
     * Returns a contiguous range of hourly ECMWF forecast data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. 
     * @param timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. 
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*  
     * @param unitScale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     * @return UvPointHourObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: kotlin.Float, longitude: kotlin.Float, timestampStart: java.time.LocalDateTime, timestampEnd: java.time.LocalDateTime, fields: kotlin.Array<kotlin.String>, unitScale: kotlin.String? = null): UvPointHourObj {
        val localVariableQuery: MultiValueMap = mapOf("fields" to toMultiValue(fields.toList(), "csv"), "unitScale" to listOf("$unitScale"))
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "timestampStart" + "}", "$timestampStart").replace("{" + "timestampEnd" + "}", "$timestampEnd"), query = localVariableQuery
        )
        val response = request<UvPointHourObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as UvPointHourObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
}
